OutgoingTile

Enum OutgoingTile 

pub enum OutgoingTile {
    Discard(Tile),
    Riichi(Tile),
    Ankan(Tile),
    Kakan {
        combination: (Tile, Tile, Tile),
        dir: Direction,
        added: Tile,
    },
    Tsumogiri,
    TsumogiriRiichi,
    Dummy,
}
Represents a tile discarded or used in an Ankan (closed Kan) or Kakan (added Kan).

Variants



Discard(Tile)

The discarded from the hand.



Riichi(Tile)

Riichi declared with a tile discarded from the hand.



Ankan(Tile)

Represents an Ankan (closed Kan).

It is likely that when an Ankan (closed Kan) is made with a 5, the red 5 is always specified (though this is not certain).



Kakan

Represents and Kakan (added Kan).

Fields

combination: (Tile, Tile, Tile)
added: Tile


Tsumogiri

Discarding the drawn tile.



TsumogiriRiichi

Declaring Riichi while discarding the drawn tile.



Dummy

Dummy tile.

When daiminkan, add dummy(Tile(0)) to align the index.